@@ -29,8 +29,8 @@
 #include <gdk/gdk.h>
 #include <glib-object.h>
 
+#include "compat-deprecated.h"
 #include "compat.h"
-#include "debug.h"
 #include "image-load.h"
 #include "image.h"
 #include "intl.h"
@@ -77,14 +77,16 @@ gboolean fullscreen_hide_mouse_cb(gpointer data)
 {
 	auto fs = static_cast<FullScreenData *>(data);
 
-	if (!fs->hide_mouse_id) return FALSE;
+	if (fs->hide_mouse_id)
+		{
+		fs->cursor_state &= ~FULLSCREEN_CURSOR_NORMAL;
+		if (!(fs->cursor_state & FULLSCREEN_CURSOR_BUSY)) clear_mouse_cursor(fs->window, fs->cursor_state);
 
-	fs->cursor_state &= ~FULLSCREEN_CURSOR_NORMAL;
-	if (!(fs->cursor_state & FULLSCREEN_CURSOR_BUSY)) clear_mouse_cursor(fs->window, fs->cursor_state);
+		g_source_remove(fs->hide_mouse_id);
+		fs->hide_mouse_id = 0;
+		}
 
-	g_source_remove(fs->hide_mouse_id);
-	fs->hide_mouse_id = 0;
-	return FALSE;
+	return G_SOURCE_REMOVE;
 }
 
 void fullscreen_hide_mouse_disable(FullScreenData *fs)
@@ -149,7 +151,7 @@ gboolean fullscreen_mouse_set_busy_cb(gpointer data)
 
 	fs->busy_mouse_id = 0;
 	fullscreen_mouse_set_busy(fs, TRUE);
-	return FALSE;
+	return G_SOURCE_REMOVE;
 }
 
 void fullscreen_mouse_set_busy_idle(FullScreenData *fs)
@@ -199,7 +201,7 @@ gboolean fullscreen_saver_block_cb(gpointer)
 		fullscreen_saver_deactivate();
 		}
 
-	return TRUE;
+	return G_SOURCE_CONTINUE;
 }
 
 gboolean fullscreen_delete_cb(GtkWidget *, GdkEventAny *, gpointer data)
@@ -237,8 +239,8 @@ GdkRectangle get_screen_default_geometry(GdkScreen *screen)
 
 	geometry.x = 0;
 	geometry.y = 0;
-	geometry.width = gdk_screen_get_width(screen);
-	geometry.height = gdk_screen_get_height(screen);
+	geometry.width = gq_gdk_screen_get_width(screen);
+	geometry.height = gq_gdk_screen_get_height(screen);
 
 	return geometry;
 }
@@ -257,7 +259,7 @@ std::vector<ScreenData> fullscreen_prefs_list()
 	for (gint j = -1; j < monitors; j++)
 		{
 		GdkRectangle rect;
-		gchar *subname;
+		g_autofree gchar *subname = nullptr;
 
 		if (j < 0)
 			{
@@ -285,8 +287,6 @@ std::vector<ScreenData> fullscreen_prefs_list()
 		        sd.number, sd.description.c_str(), sd.geometry.x, sd.geometry.y, sd.geometry.width, sd.geometry.height);
 
 		list.push_back(sd);
-
-		g_free(subname);
 		}
 
 	return list;
@@ -317,7 +317,7 @@ GdkRectangle fullscreen_prefs_get_geometry(gint screen_num, GtkWidget *widget, G
 			same_region = (!widget || !gtk_widget_get_window(widget) ||
 			               (dest_screen == gtk_widget_get_screen(widget) &&
 			                (it->number%100 == 0 ||
-			                 it->number%100 == gdk_screen_get_monitor_at_window(dest_screen, gtk_widget_get_window(widget)) + 1)));
+			                 it->number%100 == gq_gdk_screen_get_monitor_at_window(dest_screen, gtk_widget_get_window(widget)) + 1)));
 			return it->geometry;
 			}
 		}
@@ -391,8 +391,24 @@ void fullscreen_prefs_selection_add(GtkListStore *store, const gchar *text, gint
 					 FS_MENU_COLUMN_VALUE, value, -1);
 }
 
-} // namespace
+gint get_monitor_index(GdkDisplay *display, GdkMonitor *target_monitor)
+{
+	gint num_monitors = gdk_display_get_n_monitors(display);
 
+	for (gint i = 0; i < num_monitors; i++)
+		{
+		GdkMonitor *monitor = gdk_display_get_monitor(display, i);
+
+		if (monitor == target_monitor)
+			{
+			return i;
+			}
+		}
+
+	return -1; // Monitor not found
+}
+
+} // namespace
 
 /*
  *----------------------------------------------------------------------------
@@ -404,8 +420,10 @@ FullScreenData *fullscreen_start(GtkWidget *window, ImageWindow *imd,
 				 FullScreenData::StopFunc stop_func, gpointer stop_data)
 {
 	FullScreenData *fs;
-	GdkScreen *screen;
+	GdkDisplay *display;
 	GdkGeometry geometry;
+	GdkMonitor *monitor;
+	GdkScreen *screen;
 
 	if (!window || !imd) return nullptr;
 
@@ -473,14 +491,25 @@ FullScreenData *fullscreen_start(GtkWidget *window, ImageWindow *imd,
 			gdk_window_set_fullscreen_mode(gdkwin, GDK_FULLSCREEN_ON_ALL_MONITORS);
 		}
 
-	/* make window fullscreen -- let Gtk do it's job, don't screw it in any way */
-	gtk_window_fullscreen(GTK_WINDOW(fs->window));
+	auto monitor_number = options->fullscreen.screen;
 
-	/* move it to requested screen */
-	if (options->fullscreen.screen >= 0)
+	if (monitor_number < 0)
 		{
-		gtk_window_set_screen(GTK_WINDOW(fs->window), screen);
+		monitor_number = 0;
 		}
+	else if (monitor_number == 1)
+		{
+		display = gtk_widget_get_display(window);
+		monitor = gdk_display_get_monitor_at_window(display, gtk_widget_get_window(window));
+
+		monitor_number = get_monitor_index(display, monitor);
+		}
+	else if (monitor_number >= 100)
+		{
+		monitor_number = (monitor_number % 100) - 1;
+		}
+
+	gq_gtk_window_fullscreen_on_monitor(GTK_WINDOW(fs->window), screen, monitor_number);
 
 	fs->imd = image_new(FALSE);
 
@@ -522,7 +551,7 @@ FullScreenData *fullscreen_start(GtkWidget *window, ImageWindow *imd,
 	clear_mouse_cursor(fs->window, fs->cursor_state);
 
 	/* set timer to block screen saver */
-	fs->saver_block_id = g_timeout_add(60 * 1000, fullscreen_saver_block_cb, fs);
+	fs->saver_block_id = g_timeout_add(60 * 1000, fullscreen_saver_block_cb, nullptr);
 
 	/* hide normal window */
 	 /** @FIXME properly restore this window on show
@@ -531,7 +560,11 @@ FullScreenData *fullscreen_start(GtkWidget *window, ImageWindow *imd,
 		{
 		if (options->hide_window_in_fullscreen)
 			{
-			gtk_widget_hide(fs->normal_window);
+			/** @FIXME Wayland corrupts the size and position of the window when restoring it */
+			if (!g_getenv("WAYLAND_DISPLAY"))
+				{
+				gtk_widget_hide(fs->normal_window);
+				}
 			}
 		image_change_fd(fs->normal_imd, nullptr, image_zoom_get(fs->normal_imd));
 		}
@@ -552,14 +585,18 @@ void fullscreen_stop(FullScreenData *fs)
 
 	fullscreen_hide_mouse_disable(fs);
 	fullscreen_busy_mouse_disable(fs);
-	gdk_keyboard_ungrab(GDK_CURRENT_TIME);
+	gq_gdk_keyboard_ungrab(GDK_CURRENT_TIME);
 
 	if (fs->same_region)
 		{
 		image_move_from_image(fs->normal_imd, fs->imd);
 		if (options->hide_window_in_fullscreen)
 			{
-			gtk_widget_show(fs->normal_window);
+			/** @FIXME Wayland corrupts the size and position of the window when restoring it */
+			if (!g_getenv("WAYLAND_DISPLAY"))
+				{
+				gtk_widget_show(fs->normal_window);
+				}
 			}
 		if (options->stereo.enable_fsmode)
 			{
