@@ -24,9 +24,9 @@
 
 #include <glib.h>
 
-struct FileData;
+class FileData;
 struct PanWindow;
 
-void pan_timeline_compute(PanWindow *pw, FileData *dir_fd, gint *width, gint *height);
+void pan_timeline_compute(PanWindow *pw, FileData *dir_fd, gint &width, gint &height);
 
 #endif
