@@ -21,6 +21,7 @@
 
 #include "view-file-icon.h"
 
+#include <algorithm>
 #include <cstring>
 #include <utility>
 
@@ -28,8 +29,8 @@
 
 #include "cellrenderericon.h"
 #include "collect.h"
+#include "compat-deprecated.h"
 #include "compat.h"
-#include "debug.h"
 #include "dnd.h"
 #include "filedata.h"
 #include "intl.h"
@@ -181,7 +182,7 @@ static gint vficon_get_icon_width(ViewFile *vf)
 	if (!VFICON(vf)->show_text && !vf->marks_enabled ) return options->thumbnails.max_width;
 
 	width = options->thumbnails.max_width + options->thumbnails.max_width / 2;
-	if (width < THUMB_MIN_ICON_WIDTH) width = THUMB_MIN_ICON_WIDTH;
+	width = std::max(width, THUMB_MIN_ICON_WIDTH);
 	if (width > THUMB_MAX_ICON_WIDTH) width = options->thumbnails.max_width;
 	if (vf->marks_enabled && width < THUMB_MIN_ICON_WIDTH_WITH_MARKS) width = THUMB_MIN_ICON_WIDTH_WITH_MARKS;
 
@@ -355,21 +356,22 @@ static void tip_hide(ViewFile *vf)
 
 static gboolean tip_schedule_cb(gpointer data)
 {
-	auto vf = static_cast<ViewFile *>(data);
-	GtkWidget *window;
+	auto *vf = static_cast<ViewFile *>(data);
 
-	if (!VFICON(vf)->tip_delay_id) return FALSE;
-
-	window = gtk_widget_get_toplevel(vf->listview);
-
-	if (gtk_widget_get_sensitive(window) &&
-	    gtk_window_has_toplevel_focus(GTK_WINDOW(window)))
+	if (VFICON(vf)->tip_delay_id)
 		{
-		tip_show(vf);
+		GtkWidget *window = gtk_widget_get_toplevel(vf->listview);
+
+		if (gtk_widget_get_sensitive(window) &&
+		    gtk_window_has_toplevel_focus(GTK_WINDOW(window)))
+			{
+			tip_show(vf);
+			}
+
+		VFICON(vf)->tip_delay_id = 0;
 		}
 
-	VFICON(vf)->tip_delay_id = 0;
-	return FALSE;
+	return G_SOURCE_REMOVE;
 }
 
 static void tip_schedule(ViewFile *vf)
@@ -889,8 +891,7 @@ static void vficon_move_focus(ViewFile *vf, gint row, gint col, gboolean relativ
 		new_col = VFICON(vf)->focus_column;
 
 		new_row += row;
-		if (new_row < 0) new_row = 0;
-		if (new_row >= VFICON(vf)->rows) new_row = VFICON(vf)->rows - 1;
+		new_row = CLAMP(new_row, 0, VFICON(vf)->rows - 1);
 
 		while (col != 0)
 			{
@@ -1033,7 +1034,7 @@ static gint page_height(ViewFile *vf)
 	if (VFICON(vf)->show_text) row_height += options->thumbnails.max_height / 3;
 
 	ret = page_size / row_height;
-	if (ret < 1) ret = 1;
+	ret = std::max(ret, 1);
 
 	return ret;
 }
@@ -1233,7 +1234,7 @@ gboolean vficon_press_cb(ViewFile *vf, GtkWidget *, GdkEventButton *bevent)
 	return FALSE;
 }
 
-gboolean vficon_release_cb(ViewFile *vf, GtkWidget *widget, GdkEventButton *bevent)
+gboolean vficon_release_cb(ViewFile *vf, GtkWidget *, GdkEventButton *bevent)
 {
 	GtkTreeIter iter;
 	FileData *fd = nullptr;
@@ -1241,7 +1242,7 @@ gboolean vficon_release_cb(ViewFile *vf, GtkWidget *widget, GdkEventButton *beve
 
 	tip_schedule(vf);
 
-	if (defined_mouse_buttons(widget, bevent, vf->layout))
+	if (defined_mouse_buttons(bevent, vf->layout))
 		{
 		return TRUE;
 		}
@@ -1512,7 +1513,7 @@ static void vficon_populate_at_new_size(ViewFile *vf, gint w, gint, gboolean for
 	thumb_width = vficon_get_icon_width(vf);
 
 	new_cols = w / (thumb_width + (THUMB_BORDER_PADDING * 6));
-	if (new_cols < 1) new_cols = 1;
+	new_cols = std::max(new_cols, 1);
 
 	if (!force && new_cols == VFICON(vf)->columns) return;
 
@@ -1676,18 +1677,11 @@ FileData *vficon_star_next_fd(ViewFile *vf)
 			GList *list;
 			gtk_tree_model_get(store, &iter, FILE_COLUMN_POINTER, &list, -1);
 
-			for (; list; list = list->next)
+			for (GList *work = list; work; work = work->next)
 				{
-				auto fd = static_cast<FileData *>(list->data);
+				auto *fd = static_cast<FileData *>(work->data);
 				if (fd && fd->rating == STAR_RATING_NOT_READ)
 					{
-					vf->stars_filedata = fd;
-
-					if (vf->stars_id == 0)
-						{
-						vf->stars_id = g_idle_add_full(G_PRIORITY_LOW, vf_stars_cb, vf, nullptr);
-						}
-
 					return fd;
 					}
 				}
@@ -1698,20 +1692,12 @@ FileData *vficon_star_next_fd(ViewFile *vf)
 
 	/* Then iterate through the entire list to load all of them. */
 
-	GList *work;
-	for (work = vf->list; work; work = work->next)
+	for (GList *work = vf->list; work; work = work->next)
 		{
-		auto fd = static_cast<FileData *>(work->data);
+		auto *fd = static_cast<FileData *>(work->data);
 
 		if (fd && fd->rating == STAR_RATING_NOT_READ)
 			{
-			vf->stars_filedata = fd;
-
-			if (vf->stars_id == 0)
-				{
-				vf->stars_id = g_idle_add_full(G_PRIORITY_LOW, vf_stars_cb, vf, nullptr);
-				}
-
 			return fd;
 			}
 		}
@@ -1758,8 +1744,10 @@ static gboolean vficon_refresh_real(ViewFile *vf, gboolean keep_position)
 		{
 		ret = filelist_read(vf->dir_fd, &new_filelist, nullptr);
 		new_filelist = file_data_filter_marks_list(new_filelist, vf_marks_get_filter(vf));
+
+		g_autoptr(GRegex) filter = vf_file_filter_get_filter(vf);
 		new_filelist = g_list_first(new_filelist);
-		new_filelist = file_data_filter_file_filter_list(new_filelist, vf_file_filter_get_filter(vf));
+		new_filelist = file_data_filter_file_filter_list(new_filelist, filter);
 
 		new_filelist = g_list_first(new_filelist);
 		new_filelist = file_data_filter_class_list(new_filelist, vf_class_get_filter(vf));
@@ -1926,7 +1914,7 @@ static void vficon_cell_data_cb(GtkTreeViewColumn *, GtkCellRenderer *cell,
 
 		g_assert(fd->magick == FD_MAGICK);
 
-		GString *name_sidecars = g_string_new(nullptr);
+		g_autoptr(GString) name_sidecars = g_string_new(nullptr);
 
 		if (VFICON(vf)->show_text)
 			{
@@ -1939,9 +1927,8 @@ static void vficon_cell_data_cb(GtkTreeViewColumn *, GtkCellRenderer *cell,
 
 			if (fd->sidecar_files)
 				{
-				gchar *sidecars = file_data_sc_list_to_string(fd);
+				g_autofree gchar *sidecars = file_data_sc_list_to_string(fd);
 				g_string_append_printf(name_sidecars, " %s", sidecars);
-				g_free(sidecars);
 				}
 			else if (fd->disable_grouping)
 				{
@@ -1956,12 +1943,11 @@ static void vficon_cell_data_cb(GtkTreeViewColumn *, GtkCellRenderer *cell,
 				name_sidecars = g_string_append_c(name_sidecars, '\n');
 				}
 
-			gchar *star_rating = (fd->rating != STAR_RATING_NOT_READ) ? convert_rating_to_stars(fd->rating) : nullptr;
+			g_autofree gchar *star_rating = (fd->rating != STAR_RATING_NOT_READ) ? convert_rating_to_stars(fd->rating) : nullptr;
 			name_sidecars = g_string_append(name_sidecars, star_rating);
-			g_free(star_rating);
 			}
 
-		GtkStyle *style = gtk_widget_get_style(vf->listview);
+		GtkStyle *style = gq_gtk_widget_get_style(vf->listview);
 		GtkStateType state = (fd->selected & SELECTION_SELECTED) ? GTK_STATE_SELECTED : GTK_STATE_NORMAL;
 
 		GdkRGBA color_fg;
@@ -1985,7 +1971,6 @@ static void vficon_cell_data_cb(GtkTreeViewColumn *, GtkCellRenderer *cell,
 		             "foreground-set", TRUE,
 		             "has-focus", VFICON(vf)->focus_fd == fd,
 		             NULL);
-		g_string_free(name_sidecars, TRUE);
 		}
 	else
 		{
